package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````:R%```````!``````````)"S````
M`````````$``.``)`$``'``;``8````%````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````=`````````!T``````````0`````````!````
M!0````````````````!``````````$```````"RA````````+*$`````````
M`"````````$````&````P*T```````#`K6```````,"M8```````D`0`````
M``!H"0``````````(````````@````8```#8K0```````-BM8```````V*U@
M```````@`@```````"`"````````"``````````$````!````%@"````````
M6`)```````!8`D```````$0`````````1``````````$`````````%#E=&0$
M````*)H````````HFD```````"B:0```````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````,"M````````P*U@``````#`K6``
M`````$`"````````0`(````````!`````````"]L:6(O;&0M:V9R965B<V0M
M>#@V+38T+G-O+C$`````!````!`````!````1TY5``,````(`````P``````
M```$````%`````,```!'3E4`?5VYK\KM?B?(#%(:&E2>B!+J9/P`````$0``
M`$0````$````"````"`<$``%0`2&*@)``)"&`:C"*0`@22`$"[BB.$TZ!`8*
M1````$4```!)````3@```$\```!6````6````%H```!>````8`````````!B
M````90````````!F``````````````![\$IK;L7?'^K3[P[.WD<M:W^:?"[%
MF[8@_^0.?$&.Q;B-\0[59-1\V7%8'.)'Q@&L2^/`\MO3';KCDGS"Y3\L^J%L
M8+,!BV]J"4/6A_F<@6:OS&;%N9Q`0D75[,2)!9"(!W#3.?*+'`P4XI[)U;)Q
MVLWCGC-BV^T,.I<+5J2;EJ?=HVM_J9R;"HH05Z/@^TD`````````````````
M````````````````````90,``!(`````````````````````````Y@(``!(`
M````````````````````````F@,``!(`````````````````````````20(`
M`!(`````````````````````````$0```"``````````````````````````
M4`(``!(`````````````````````````PP(``!(`````````````````````
M````F0(``!(`````````````````````````T0(``!(`````````````````
M````````TP```!(`````````````````````````C`,``!(`````````````
M````````````KP```!(`````````````````````````/0$``!(`````````
M````````````````WP(``!(`````````````````````````JP(``!(`````
M````````````````````I@$``!(`````````````````````````;`,``!(`
M````````````````````````9@$``!(`````````````````````````X0``
M`!(`````````````````````````\`$``!(`````````````````````````
MC0$``!(`````````````````````````D0(``!(`````````````````````
M````>@(``!(`````````````````````````W0$``!(`````````````````
M````````+P(``!(`````````````````````````,`,``!(`````````````
M````````````'0,``!(`````````````````````````=`$``!(`````````
M````````````````6`,``!(`````````````````````````H@(``!(`````
M````````````````````0P(``!(`````````````````````````+0```"``
M````````````````````````*`,``!(`````````````````````````"`,`
M`!(`````````````````````````>````!(`````````````````````````
M[0(``!(`````````````````````````DP,``!(`````````````````````
M````%`$``!(`````````````````````````"@0``!(`````````````````
M````````O@```!(`````````````````````````:0(``!(`````````````
M````````````FP$``!(`````````````````````````00,``!(`````````
M````````````````:@```!(`````````````````````````A`,``!(`````
M````````````````````0@$``!(`````````````````````````1P$``!(`
M````````````````````````#P,``!(`````````````````````````T@$`
M`!(`````````````````````````(0$``!(`````````````````````````
M40,``!(`````````````````````````]`(``!(`````````````````````
M````M`$``!(`````````````````````````O`(``!(`````````````````
M````````R0(``!(`````````````````````````/````"``````````````
M````````````^````!(`````````````````````````A`$``!(`````````
M````````````````V`(``!(`````````````````````````2`,``!(`````
M````````````````````80(``!(`````````````````````````^@(``!(`
M````````````````````````AP```!(`````````````````````````4```
M`"``````````````````````````Z0$``!(`````````````````````````
MC`(``!(`````````````````````````=@,``!(`````````````````````
M````P@$``!(```"`&T``````````````````$P0``!(`#0"`64```````&\`
M````````X0,``!(`#@#$6D``````````````````.`0``!(`#0`024``````
M`'`,````````IP,``!(`#0`@'T```````$L"````````YP,``!(`#0!`0D``
M``````,`````````D`0``!(`#0!00D```````,D!````````O00``!(`#0#P
M64```````#H`````````B@0``!(`"P"X&D``````````````````V00``!(`
M#0"`54`````````$````````RP,``!``&0!0LF``````````````````'P0`
M`!(`#0`@1$```````"0`````````4@0``!$`#P#06D````````0`````````
M^P$``!$`&0"PLF```````!,`````````\P```!``&0`HMV``````````````
M````B`0``!(`#0#`04```````"H`````````G00``!(`#0#`1T```````$H!
M````````KP0``!(`#0`01T```````'D`````````100``!``&``PLF``````
M````````````G@```!(```!0'D``````````````````+`0``!(`#0!01$``
M`````-D`````````K`,``!$`&0"`LF````````@`````````Q`,``!``&`!0
MLF``````````````````K0,``"$`&0"`LF````````@`````````<00``!$`
M&`!(LF````````@`````````.@,``!$`&0#(LF````````@`````````UP,`
M`!(`#0#`6D````````(`````````4P$``!(```"0'4``````````````````
M800``!(`#0!06D```````&4`````````2P0``!(`#0!K(4``````````````
M````1P0``"``&``PLF``````````````````,@$``!$`&0"(LF````````0`
M````````K@,``"$`&0"`LF````````@`````````^`,``!(`#0"01T``````
M`"0`````````!P$``!$`&0"@LF````````$`````````>P0``!(`#0`P14``
M`````-L!`````````&QI8G!E<FPN<V\N-2XR,`!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E
M<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T9F]R
M:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E
M<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V5N9`!097)L7W-V7W-E
M='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA
M9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?
M<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E
M<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB9&PN
M<V\N,@!L:6)M+G-O+C$`;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E
M8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R
M96%D`&QI8F,N<V\N,"XQ`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M
M<`!?7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M
M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!S=')S
M='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?
M7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A
M9&QI;FL`97AE8W9P`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?
M<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R
M=%]M86EN`%]?96YV:7)O;@!L:6)C<GEP="YS;RXQ`%]E9&%T80!?7V)S<U]S
M=&%R=`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA;64`
M<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D
M:6Y?=7-E9`!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N
M=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!84U]);G1E
M<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXS`$=,24)#7S(N,30`1TQ)0D-?,BXS
M+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT`````@`"``(``P````,``@`"``(`
M```"```````"``0````"`````````````@`%`````P`"``(````&``(``P``
M``(`!P````(``@````(````#`````@````(``@````8```````(``@````(`
M`@`````````"``(``P`&```````"``(`!@````$``0`!``$``0`!``$``0`!
M``$``0`!`````0`!``$``0`!`````0`"``$``@`!``(``0````$``0`!````
M`@`!`````0````$``0`?`@``$````"`````3:6D-```#`.\$`````````0`%
M`&X"```0`````````)21E@8```<`^00``!````!T&6D)```&``0%```0````
M<AEI"0``!0`0!0``$````!1I:0T```0`'`4``!`````3:6D-```"`.\$````
M````^*]@```````&````(```````````````@+)@```````%````60``````
M````````B+)@```````%````8P``````````````H+)@```````%````9@``
M````````````L+)@```````%````40``````````````R+)@```````%````
M70``````````````&+!@```````'`````0``````````````(+!@```````'
M`````@``````````````*+!@```````'`````P``````````````,+!@````
M```'````!```````````````.+!@```````'````!@``````````````0+!@
M```````'````!P``````````````2+!@```````'````"```````````````
M4+!@```````'````"0``````````````6+!@```````'````"@``````````
M````8+!@```````'````1```````````````:+!@```````'````"P``````
M````````<+!@```````'````#```````````````>+!@```````'````#0``
M````````````@+!@```````'````#@``````````````B+!@```````'````
M#P``````````````D+!@```````'````$```````````````F+!@```````'
M````$0``````````````H+!@```````'````$@``````````````J+!@````
M```'````$P``````````````L+!@```````'````%```````````````N+!@
M```````'````%0``````````````P+!@```````'````%@``````````````
MR+!@```````'````%P``````````````T+!@```````'````&```````````
M````V+!@```````'````&0``````````````X+!@```````'````&@``````
M````````Z+!@```````'````&P``````````````\+!@```````'````'```
M````````````^+!@```````'````'0```````````````+%@```````'````
M'@``````````````"+%@```````'````'P``````````````$+%@```````'
M````(```````````````&+%@```````'````(0``````````````(+%@````
M```'````(@``````````````*+%@```````'````(P``````````````,+%@
M```````'````)```````````````.+%@```````'````)0``````````````
M0+%@```````'````)@``````````````2+%@```````'````)P``````````
M````4+%@```````'````*```````````````6+%@```````'````*0``````
M````````8+%@```````'````*@``````````````:+%@```````'````7P``
M````````````<+%@```````'````*P``````````````>+%@```````'````
M+```````````````@+%@```````'````+0``````````````B+%@```````'
M````+@``````````````D+%@```````'````+P``````````````F+%@````
M```'````,```````````````H+%@```````'````,0``````````````J+%@
M```````'````,@``````````````L+%@```````'````,P``````````````
MN+%@```````'````-```````````````P+%@```````'````-0``````````
M````R+%@```````'````5P``````````````T+%@```````'````-@``````
M````````V+%@```````'````-P``````````````X+%@```````'````.0``
M````````````Z+%@```````'````.@``````````````\+%@```````'````
M.P``````````````^+%@```````'````/````````````````+)@```````'
M````/0``````````````"+)@```````'````/@``````````````$+)@````
M```'````/P``````````````&+)@```````'````00``````````````(+)@
M```````'````0@``````````````*+)@```````'````0P``````````````
M2(/L"$B+!365(`!(A<!T!>@3`@``2(/$",,``````````````````/\U(I4@
M`/\E))4@``\?0`#_)2*5(`!H`````.G@_____R4:E2``:`$```#IT/____\E
M$I4@`&@"````Z<#_____)0J5(`!H`P```.FP_____R4"E2``:`0```#IH/__
M__\E^I0@`&@%````Z9#_____)?*4(`!H!@```.F`_____R7JE"``:`<```#I
M</____\EXI0@`&@(````Z6#_____)=J4(`!H"0```.E0_____R72E"``:`H`
M``#I0/____\ERI0@`&@+````Z3#_____)<*4(`!H#````.D@_____R6ZE"``
M:`T```#I$/____\ELI0@`&@.````Z0#_____):J4(`!H#P```.GP_O___R6B
ME"``:!````#IX/[___\EFI0@`&@1````Z=#^____)9*4(`!H$@```.G`_O__
M_R6*E"``:!,```#IL/[___\E@I0@`&@4````Z:#^____)7J4(`!H%0```.F0
M_O___R5RE"``:!8```#I@/[___\E:I0@`&@7````Z7#^____)6*4(`!H&```
M`.E@_O___R5:E"``:!D```#I4/[___\E4I0@`&@:````Z4#^____)4J4(`!H
M&P```.DP_O___R5"E"``:!P```#I(/[___\E.I0@`&@=````Z1#^____)3*4
M(`!H'@```.D`_O___R4JE"``:!\```#I\/W___\E(I0@`&@@````Z>#]____
M)1J4(`!H(0```.G0_?___R42E"``:"(```#IP/W___\E"I0@`&@C````Z;#]
M____)0*4(`!H)````.F@_?___R7ZDR``:"4```#ID/W___\E\I,@`&@F````
MZ8#]____)>J3(`!H)P```.EP_?___R7BDR``:"@```#I8/W___\EVI,@`&@I
M````Z5#]____)=*3(`!H*@```.E`_?___R7*DR``:"L```#I,/W___\EPI,@
M`&@L````Z2#]____);J3(`!H+0```.D0_?___R6RDR``:"X```#I`/W___\E
MJI,@`&@O````Z?#\____):*3(`!H,````.G@_/___R6:DR``:#$```#IT/S_
M__\EDI,@`&@R````Z<#\____)8J3(`!H,P```.FP_/___R6"DR``:#0```#I
MH/S___\E>I,@`&@U````Z9#\____)7*3(`!H-@```.F`_/___R5JDR``:#<`
M``#I</S___\E8I,@`&@X````Z6#\____)5J3(`!H.0```.E0_/___R52DR``
M:#H```#I0/S___\E2I,@`&@[````Z3#\____)4*3(`!H/````.D@_/___R4Z
MDR``:#T```#I$/S___\E,I,@`&@^````Z0#\____)2J3(`!H/P```.GP^___
M_R4BDR``:$````#IX/O___\E&I,@`&A!````Z=#[____)1*3(`!H0@```.G`
M^___4TB#[#")?"0<2(ET)!!(C7PD'$B)5"0(2(UT)!!(C50D"&1(BP0E*```
M`$B)1"0H,<#HN?W__[J0'4``OU`>0`!(B=;HQSH``(`],),@``!U+^BI_/__
M2(7`2(D%GY<@``^$V@$``$B)Q^@1_/__BSWSDB``Z-;\___&@+4'````BSWA
MDB``Z,3\__^`B-(#```"BSW/DB``Z++\__^`B-(#```!BT0D'(UX!4AC_TB%
M_P^(&P$``&8/[\#R2`\JQ_(/6`4O>@``9@\N!2]Z```/AS`!``!(P><#Z&#\
M__],BTPD$$B)!?R6(`#'!?J6(``$````28L12,=`"*-<0`!(QT`8IEQ``$B)
M$$B+%162(`!(B5`0BU0D'(/Z`7XIC4K^,?9(@\$!#Q^``````$V+1/$(C7X%
M2(/&`4@YSDAC_TR)1/CX=>>-2@1(BSVMEB``@\(#13'`OO!!0`!(8\E(QT3(
M^`````!(B<'H;OW__X7`B<-T2TB+/8&6(`#H//O__TB-="0D,<"_9UM``.A;
M&0``2(7`=%I(BSU?EB``Z.KZ___HY?S__XG82(M<)"AD2#,<)2@```!U?TB#
MQ#!;PTB+/3:6(`#HH?W__XG#ZZ5(B?A(B?IF#^_`2-'H@^(!2`G0\D@/*L#R
M#UC`Z<W^__](BSW]E2``2(7_=!CH6S@``.N3OK"R8`"_UUI``#'`Z"C\__](
MC70D)+\<6T``Z,D8``!(A<!(B<=(B07$E2``#X1@____Z\3H;_K__[\!````
MZ)7]__\Q[4F)\4B+-TB-5PA(@^3P4%1)Q\#`6D``2,?!4%I``$C'QR`?0`#H
M>?G___1(Q\`HMV``D+A7LF``54@M4+)@`$B#^`Y(B>5V&[@`````2(7`=!%=
MOU"R8`#_X&8/'X0``````%W#9F9F9F8N#Q^$``````"^4+)@`%5(@>Y0LF``
M2,'^`TB)Y4B)\$C!Z#](`<9(T?YT%;@`````2(7`=`M=OU"R8`#_X`\?`%W#
M9@\?1```@#VID"```'4154B)Y>AN____7<8%EI`@``'SPP\?0`"_T*U@`$B#
M/P!U!>N3#Q\`N`````!(A<!T\55(B>7_T%WI>O___V8N#Q^$``````!!5T%6
M3(U'.$%5050Q]E532('LF`(``&1(BP0E*````$B)A"2(`@``,<!F#Q]$``!)
MBP0P2(G"2(G!2,'B"$C!X1B!X@``_P")R4@)RDB)P4C!Z0B!X0#_``!("<I(
MB<%(P>D8#[;)2`G*2(D4=$B)PDC!ZB!)B=%(B=%)P>$(2,'A&$&!X0``_P")
MR4R)RD@)RDB)P4C!Z#A(P>DH@>$`_P``2`G*2`G02(E$=`A(@\8(2(/^0`^%
M=/___TB-5"1H2(VT)&@"```/'X``````2(M"V$@S`DB#P@A(,T*@2#-"D$B)
MP4@!P$C!Z1]("<B#X/](B4(02#GR==1,BP](BV\@3(M7"$R+7Q!(BU\82(GJ
M3(G)2`,4)$R)R$C!Z1M-B=5(P>`%2<'M`DB)WD@)R$@#="0(38G,B<!)P>P"
M2(V,`IEY@EI,B=!,B=I(]]!,(=)((=A("=!,B=)(P>(>2`'(3(G)20G52/?1
M08G'18GM3"'938GH2(G*32'(3`G"2(V,%IEY@EI,B?Y,B?I(P>X;2,'B!4@)
M\HG22(TT$4R)RDR)^4C!XAY(]]%)"=1,B=I(`U0D$$6)Y$PAZ4&)\$PAX$P#
M;"082`G!3(G`2(V4"IEY@EI,B<%(P>`%2,'I&T@)R(G`2(T,`DR)^DR)^$C!
MX!Y(P>H"2`G"3(G`08G.B=)(]]!,(>!((=9,`V0D($@)QDR)\$F-M#69>8):
M38GU2,'@!4G![1M,">B)P$R-+`9,B<!)P>`>2,'H`DD)P$R)\$6)[T6)P$CW
MT$@AT$PAP4@#5"0H2`G!3(GX28VT#)EY@EI,B?E(P>`%2,'I&T@)R(G`2(T,
M!DR)\$G!YAY(P>@"3(G^20G&2/?608G,1(GP3"'&3`-$)#!)(<5)"?5,B>9.
MC:PJF7F"6DR)XDC!Y@5(P>H;2`GR3(G^2<'G'DC![@*)TDP!ZDD)]TV)Y42)
M_DGWU4&)UDDAQ4@A\4P)Z4V-K`B9>8):38GP3(GQ2<'H&TC!X05(`T0D.$P)
MP8G)38U$#0!,B>%)P>0>2,'I`DD)S$6)Q42)X4V)]$GWU$@ARDDA]$@#="1`
M3`GB3(VD$)EY@EI,B>A,B>I(P>(%2,'H&T@)T$R)\DG!YAY(P>H"B<!)"=9,
M`>!$B?)-B>Y!B<1)]]9)(=!)(<Y(`TPD2$T)\$Z-M`:9>8):3(GF38G@2<'@
M!4C![AM,"<9-B>A)P>4>2<'H`HGV30G%3`'V18GH38GE08GV2??53"'`22'5
M3`GH3(VL`9EY@EI,B?%,B?!(P>D;2,'@!4@#5"102`G(B<!)C4P%`$R)X$G!
MY!Y(P>@"20G$08G-1(G@38GT2??42"'&32'$3`-$)%A,">9,C:0RF7F"6DR)
MZDR)[DC!Y@5(P>H;2`GR3(GV2<'F'DC![@*)TDD)]DP!XD2)]DV)[D&)U$GW
MUD@A\4DAQD@#1"1@3`GQ38VT")EY@EI-B>!,B>%)P>@;2,'A!4P)P8G)38T$
M#DR)Z4G!Y1Y(P>D"20G-18G&1(GI38GE2??52"'*22'U3`GJ3(VL$)EY@EI,
MB?!,B?)(P>(%2,'H&T@)T$R)XHG`3`'H2,'J`DG!Y!Y)"=1(`W0D:$&)Q42)
MXDV)]$GWU$DAT$DAS$@#3"1P30G@3HVD!IEY@EI,B>Y-B>A)P>`%2,'N&TP)
MQDV)\$G!YAY)P>@"B?9-"<9,`>9%B?!-B>Y!B?1)]]9,(<!)(=9(`U0D>$P)
M\$R-M`&9>8):3(GA3(G@2,'I&TC!X`5("<B)P$F-#`9,B>A)P>4>2,'H`DD)
MQ4&)ST2)Z$V)Y4GWU4@AQDTAQ4P)[DR-K#*9>8):3(GZ3(G^2,'F!4C!ZAM(
M"?),B>:)TDP!ZDC![@))P>0>20GT3`.$)(````!!B=9$B>9-B?Q-B?5)]]1(
M(?%)P>T;22'$2`.$)(@```!,">%-C80(F7F"6DR)\4C!X05,">F)R4V-+`A,
MB?E)P><>2,'I`DV)\$D)STGWT$6)[$2)^4DA\$@#M"20````2"'*3`G"38G@
M2(V4$)EY@EI,B>!)P>@;2,'@!4P)P(G`3(T$`DR)\DG!YAY(P>H"20G61(G`
M1(GR38GF28G'2??622'52<'O&TDASDT)]4Z-K"Z9>8):2(G&2,'F!4P)_HGV
M38U\-0!-B>5)P>0>2<'M`DB)QDT)Y4@#C"28````2/?618GL2"'618G^32'@
M2`.4)*````!,`Z0DJ````$D)\$R)]DZ-A`&9>8):3(GQ2,'N&TC!X05("?&)
MR4F--`A(B<%(P>`>2,'I`D@)R$&)\$DQQ44Q[TV)Q4J-C#JAZ]EN3(G"2<'M
M&TC!X@5,">J)TDR-+!%,B?%)P>8>2,'I`DP)\46)[TB)RD@QPHG`2`.$)+``
M```QUDR)^DV-I#2AZ]EN3(G^2,'B!4C![AM("?*)TDF--!1-B<1)P>`>2<'L
M`DT)Q(GR38G@23'(B<E%,<5)B=!.C:PHH>O9;DB)T$G!X`5(P>@;3`G`38GX
M2<'G'DG!Z`)(`XPDN````(G`30GX3`'H38G%08G&33'E1#'N3(VL,:'KV6Y,
MB?%,B?9(P>8%2,'I&T@)\4B)UDC!XAY(P>X"B<E("=9$B>)(`Y0DP````$F)
M]$P!Z4TQQ$&)ST6)P$0QX$P#A"3(````3(VD`J'KV6Y,B?A,B?I(P>(%2,'H
M&T@)T$R)\DG!YAY(P>H"B<!,"?),`>!)B=1!B<5),?2)]D0QX4V-I`BAZ]EN
M38GH3(GI2<'H&TC!X05,"<&)R4V-!`Q,B?E)P><>2,'I`DP)^4@#M"30````
M18G&28G,23'4B=)(`Y0DV````$0QX$R-I`:AZ]EN3(GV3(GP2,'N&TC!X`5(
M"?")P$F--`1,B>A)P>4>2,'H`DP)Z$&)]$F)Q4DQS8G)2`.,).````!%,>A.
MC:P"H>O9;DR)XDV)X$G!X`5(P>H;3`G"38GP2<'F'DG!Z`*)TDT)\$P!ZDV)
MQD&)U4DQQHG`2`.$).@```!$,?9,C;0QH>O9;DR)Z4R)[DC!Y@5(P>D;2`GQ
M3(GF2<'D'DC![@*)R4P)YDP!\4F)]$&)SDTQQ$6)P$0QXDR-I!"AZ]EN3(GP
M3(GR2,'H&TC!X@5,`X0D\````$@)T$R)ZDG!Y1Y(P>H"B<!,">I,`>!)B=5!
MB<1),?6)]D@#M"3X````1#'I38VL"*'KV6Y-B>!,B>%)P>@;2,'A!4P)P8G)
M38U$#0!,B?%)P>8>2,'I`DP)\46)Q4F)SDDQUHG22`.4)``!``!$,?!,C;0&
MH>O9;DR)[DR)Z$C![AM(P>`%2`GPB<!)C30&3(G@2<'D'DC!Z`),">!!B?9)
MB<1),<R)R44QX$Z-I`*AZ]EN3(GR38GP2<'@!4C!ZAM,"<)-B>B)TDG!Z`),
M`>))P>4>2`.,)`@!``!-">A!B=1-B<5),<6)P$@#A"00`0``1#'N3(VL,:'K
MV6Y,B>%,B>9(P>8%2,'I&T@)\4R)]DG!YAY(P>X"B<E,"?9,`>E)B?9!B<U-
M,<9%B<!,`X0D&`$``$0Q\DR-M!"AZ]EN3(GH3(GJ2,'B!4C!Z!M("=!,B>))
MP>0>2,'J`HG`3`GB3`'P28G408G&23'TB?9(`[0D(`$``$0QX4V)]$V-A`BA
MZ]EN3(GQ2<'L&TC!X05,">&)R4V-)`A,B>E)P>4>2,'I`DP)Z46)X$F)S4DQ
MU8G21#'H2`.4)"@!``!,C:P&H>O9;DR)QDR)P$C![AM(P>`%2`GPB<!)C70%
M`$R)\$G!YAY(P>@"3`GP08GU28G&23'.B<E(`XPD,`$``$4Q]$Z-M"*AZ]EN
M3(GJ38GL2<'D!4C!ZAM,">)-B<1)P>`>2<'L`HG230G$3`'R38G@08G723'`
MB<!(`X0D.`$``$0QQDR-A#&AZ]EN3(G^3(GY2,'N&TC!X05("?&)R4F--`A-
MB>A)P>4>2<'H`DT)Z$&)]DR)P4V)]4PQX4G![1M%B>0QRDB-E!"AZ]EN3(GP
M2,'@!4P)Z(G`3(TL`DR)^KC<O!N/2,'J`DG!YQY,"?I)B<=,`[PD0`$``$2)
MZ4T!_$F)UTT)QTPA_DF)UTTAQT6)P$0)_DF)STD!]$B)SDG![QM(P>8%3`G^
MB?9-C3PT3(GV2<'F'DC![@),"?9)B<9,`[0D2`$``$6)_$T!\$F)]DD)UDTA
M]4F)]DDAUHG210GU38GF30'H38GE2<'N&TG!Y05-"?5%B>U-`<5)B<A(P>$>
M2<'H`D6)[DP)P4F)P$P#A"10`0``3`'"28G(20GP32''28G(22'PB?9%"<=-
MB?!,`?I-B?=)P>`%2<'O&TT)^$6)P$D!T$R)XDG!Y!Y(P>H"18G'20G42(G"
M2`.4)%@!``!(`?),B>9("<Y)(?5,B>9((<Z)R4$)]4R)_DP!ZDV)_4C!Y@5)
MP>T;3`GNB?9,C2PR3(GR2<'F'DC!Z@),"?))B<9,`[0D8`$``$2)[DP!\4F)
MUDT)YDTA\$F)UDTAYD6)Y$4)\$F)]DP!P4F)\$G![AM)P>`%30GP18G`3HTT
M`4V)^$G!Z`))P><>30GX28G'3`.\)&@!``!$B?%-`?Q-B<=)"==-(?U-B<=)
M(=>)TD4)_4F)STT![$F)S4G![QM)P>4%30G]18GM30'E28GT2,'F'DG![`)%
MB>],">9)B<1,`Z0D<`$``$P!XDF)]$T)Q$TAYDF)]$TAQ$6)P$4)YDV)_$P!
M\DV)_DG!Y`5)P>X;30GT18GD20'42(G*2,'A'DC!Z@)%B>9("=%(B<)(`Y0D
M>`$``$P!PDF)R$D)\$TAQ4F)R$DA\(GV10G%38GP3`'J38GU2<'@!4G![1M-
M">A%B<!)`=!,B?I)P><>2,'J`D6)Q4P)^DF)QTP#O"2``0``3`'^28G720G/
M32'\28G722'/B<E%"?Q.C3PF38GL3(GN2,'F!4G![!M)"?1%B>1+C30G38GT
M2<'F'DG![`)-"?1)B<9,`[0DB`$``$&)]TP!\4V)YDD)UDTA\$V)YDDAUHG2
M10GP3HTT`4V)^$R)^4C!X05)P>@;20G(18G`2XT,!DV)Z$G!Z`))P>4>30GH
M28G%3`.L))`!``!!B<Y,`>I-B<5-">5,(>Y-B<5-(>5%B>1$">Y-B?5(`?),
MB?9)P>T;2,'F!4P)[HGV3(TL,DR)_DG!YQY(P>X"3`G^28G'3`.\))@!``!$
MB>I-`?Q)B?=-"<=,(?E)B?=-(<=%B<!$"?E)B==)`<Q(B=%)P>\;2,'A!4P)
M^8G)38T\#$R)\4G!YAY(P>D"3`GQ28G&3`.T)*`!``!%B?Q-`?!)B<Y)"?9-
M(?5)B<Y)(?:)]D4)]4V)YDT!Z$V)Y4G![AM)P>4%30GU18GM30'%28G02,'B
M'DG!Z`)%B>Y,"<))B<!,`X0DJ`$``$P!QDF)T$D)R$TAQTF)T$DAR(G)10G'
M38GP3`'^38GW2<'@!4G![QM-"?A%B<!)`?!,B>9)P>0>2,'N`D6)QTD)]$B)
MQD@#M"2P`0``2`'Q3(GF2`G622'U3(GF2"'6B=)!"?5,B?Y,`>E-B?U(P>8%
M2<'M&TP)[HGV3(TL,4R)]DG!YAY(P>X"3`GV28G&3`.T)+@!``!$B>E,`?))
MB?9-">9-(?!)B?9-(>9%B>1%"?!)B<Y,`<))B<A)P>X;2<'@!4T)\$6)P$Z-
M-`)-B?A)P><>2<'H`DT)^$F)QTP#O"3``0``1(GR30'\38G'20GW32']38G'
M22'WB?9%"?U)B==-`>Q)B=5)P>\;2<'E!4T)_46)[4T!Y4F)S$C!X1Y)P>P"
M18GO3`GA28G$3`.D),@!``!,`>9)B<Q-"<1-(>9)B<Q-(<1%B<!%">9-B?Q,
M`?9-B?Y)P>0%2<'N&TT)]$6)Y$Z--"9(B=9(P>(>2,'N`D@)\DB)QD@#M"30
M`0``18GT2`.$)-@!``!,`<9)B=!)"<A-(<5)B=!)(<B)R44)Q4V)X$@!R$P!
M[DV)Y4G!X`5)P>T;30GH18G`3HTL!DR)_DG!YQY(P>X"3`G^18GH2(GQ2`G1
M22'.2(GQ2"'1B=)!"<Y,B<%,`?!-B<9(P>$%2<'N&TP)\8G)3(TT"$R)X$G!
MY!Y(P>@"20G$N-;!8LI$B?%)B<=,`[PDX`$``$P!^DV)YTDQ]XGV13']28G/
M3`'J28G-2<'O&TG!Y05-"?U-B<=)P>`>2<'O`D6)[4T)^$F)QTP#O"3H`0``
M20'51(GJ3`'^38G'33'G18GD13'^28G73`'V28G62<'O&TG!Y@5-"?Y)B<](
MP>$>2<'O`D6)]DD)STB)P4@#C"3P`0``20'V1(GV3`'A38G\33'$18G`13'E
M28GT3`'I28GU2<'M&TG!Y`5-">5)B=1(P>(>2<'L`D6)[4D)U$B)PD@#E"3X
M`0``20'-1(GI3`'"38G@33'X18G_13'&28G(3`'R28G.2<'@!4G![AM-"<9%
MB?9)`=9(B?)(P>8>2,'J`D6)\$@)UDB)PD@#E"0``@``3`'Z28GW33'G18GD
M13']38G'3`'J38G%2<'O&TG!Y05-">])B<U(P>$>2<'M`D6)_TD)S4B)P4@#
MC"0(`@``20'71(GZ3`'A38GL23'TB?9%,>9)B=1,`?%)B=9)P>0%2<'N&TT)
MYD6)]DD!SDR)P4G!X!Y(P>D"18GT20G(2(G!2`.,)!`"``!(`?%,B<9,,>Y%
MB>U!,?=,B>9,`?E-B>=(P>8%2<'O&TD)]TB)UDC!XAY(P>X"18G_2`G62(G"
M2`.4)!@"``!)`<]$B?E,`>I)B?5-,<5%B<!%,>Y)B<U,`?))B<Y)P>4%2<'N
M&TT)[D6)]DD!UDR)XDG!Y!Y(P>H"18GU20G42(G"2`.4)"`"``!,`<)-B>!)
M,?")]D4QQTV)Z$P!^DV)[TG!X`5)P>\;30G'28G(2,'A'DG!Z`)%B?])"<A(
MB<%(`XPD*`(``$D!UT2)^D@!\4R)QDPQYD6)Y$$Q]DB)UDP!\4F)UDC!Y@5)
MP>X;20GV18GV20'.3(GI2<'E'DC!Z0)$B?9)"<U(B<%(`XPD,`(``$P!X4V)
M[$TQQ$6)P$4QYTF)]$P!^4F)]TG!Y`5)P>\;30GG28G418G_20'/2,'B'DG!
M[`))"=1(B<)(`Y0D.`(``$2)^4P!PDV)X$TQZ$6)[44QQDF)R$P!\DF)SDG!
MX`5)P>X;30G&18GV20'62(GR2,'F'DC!Z@)%B?!("=9(B<)(`Y0D0`(``$P!
MZDF)]4TQY46)Y$4Q[TV)Q4P!^DV)QTG!Y05)P>\;30GO28G-2,'A'DG![0)%
MB?])"<U(B<%(`XPD2`(``$D!UT2)^DP!X4V)[$DQ](GV13'F28G43`'Q28G6
M2<'N&TG!Y`5-">9%B?9)`<Y,B<%)P>`>2,'I`D6)]$D)R$B)P4@#C"10`@``
M2`'Q3(G&3#'N18GM03'W3(GF3`'Y38GG2,'F!4G![QM)"?=(B=9(P>(>2,'N
M`D6)_T@)UDB)PD@#E"18`@``20'/1(GY3`'J28GU33'%18G`13'N28G-3`'R
M28G.2<'E!4G![AM-"?5%B>U)`=5,B>))P>0>2,'J`D6)[DD)U$B)PD@#E"1@
M`@``3`'"38G@23'PB?9%,<=-B?!,`?I-B?=)P>`%2<'O&TT)^$F)STC!X1Y)
MP>\"18G`3`GY28G'3`.\)&@"``!,`<)!B=!,`?Y)B<]-,>=%B>1%,?U-B<=,
M`>Y-B<5)P>\;2<'E!4T)_4V)]TG!YAY)P>\"18GM30G^28G'3`.\)'`"``!,
M`>Y!B?5-`?Q-B?=),<^)R40Q^DV)[TD!U$R)ZDG![QM(P>(%3`GZ1`'B38G$
M2<'@'DG![`)-">!(`X0D>`(``$V)[$G![`))P>4>1`'U30GE2(EO($4!ZTR-
M)`A,B<%(B=!,,?%(P>`%00'8,<Y,B5\03(E'&$F-##1(B=9$`=)(P>X;2(E7
M"$@)\`'(00'!2(N$)(@"``!D2#,$)2@```!,B0]U$DB!Q)@"``!;74%<05U!
M7D%?P^C%X?__#Q]$``!!5T%628G^055!5%532(/L"$B%_W1H3(L]4W@@`$V%
M_W1<#[8'28GU/#UT9(3`=&!)B?Q)@\0!00^V!"0\/70$A,!U[T4I]$F+'TB%
MVW0O36/D3(G]#Q\`3(GB3(GV2(G?Z,KA__^%P'4'0H`\(SUT)TB#Q0A(BUT`
M2(7;==I(@\0(,<!;74%<05U!7D%?PY!%,>3KL@\?`$PI_4J-1",!2,']`T&)
M;0!(@\0(6UU!7$%=05Y!7\-F#Q^$``````!32(G[2(/L$&1(BP0E*````$B)
M1"0(,<`/'X0``````$B-="0$,<!(B=_H$?___TB%P'0N2&-4)`1(BP5P=R``
M2(T$T$B+4`A(A=)(B1!TT$B#P`A(BU`(2(722(D0=?#KODB+1"0(9$@S!"4H
M````=09(@\006\/H@^#__P\?`$%7059!54%455-(B?-(B?U(@^P89$B+!"4H
M````2(E$)`@QP#'`@#X]#Y3`2`'#2(G?Z'G?__](C70D!$F)Q$B)[S'`Z'?^
M__](A<!)B<4/A`L!``!(B<?H4]___T2)XD@YT`^#UP```(M$)`0/ME4`@/H]
M#X2<`0``A-(/A)0!``!(B>KK#68/'X0``````(3)=`Q(@\(!#[8*@/D]=?`I
MZDB+#8=V(`!"C7PB`DR-+,'HZ>+__TB%P$F)10`/A&8!``"+5"0$2(L%878@
M`$B-30%(BQ30#[9%`(3`B`)U&>L;#Q]$``!(@\$!#[9!_TB#P@&$P(@"=`0\
M/77JQ@(],<`/'T0```^V#`.(3`(!2(/``83)=?`QP$B+="0(9$@S-"4H````
M#X4&`0``2(/$&%M=05Q!74%>05_##Q\`2(/#`0^V0_])@\4!A,!!B$7_=>SK
MPF8N#Q^$``````!,BS7)=2``28,^``^$K````$R)\#'29BX/'X0``````$B#
MP`B#P@%(@S@`=?.-0@)!B=5(F$B-/,4`````BP4->B``A<!T.4B)_DR)]^AN
MX?__2(7`2(D%='4@`'1L36/]2(G!1(GH2L=$^0@`````B40D!.F4_O__#Q^`
M`````,<%QGD@``$```#HL>'__TB%P'0V36/]3(GV2(G'2HT4_0````#H9N#_
M_TB)P4B)!1QU(`#KKC'2Z87^__^_$````$4Q[>ES____N/_____IYO[__^A'
MWO__#Q^``````$%505154TB)_4B![)@```!D2(L$)2@```!(B80DB````#'`
M2(7_=`6`/P!U*TB+A"2(````9$@S!"4H````#X4;`0``2('$F````%M=05Q!
M7<-F#Q]$``#H`]___TB%P$F)Q'3(3(GGZ//=__](A<!(B<,/A)\```"`>P@N
M#X2M````2(/#"$B)[^CAW/__2(G?28G%Z-;<__]!C7P%`DAC_^BYX/__28G9
M28G%2(G'28GHN=1:0`!(Q\+_____O@$````QP.BUX/__OP,```!(B>),B>[H
M%=[__X/X_TR)[W0/#[=$)!!F)0#P9CT`0'1FZ-G?__],B>_H0=___TR)Y^A9
MW?__2(7`2(G##X5F____#Q]$``!,B>?H$-[__TB)[^AXW___Z0#___\/'P`/
MMD,)A,`/A"G___\\+@^%/____X!["@`/A!?____I,/___P\?1```Z*/^___K
MF.C<W/__9F9F+@\?A```````55-(@^P(BSU\<R``Z%_=__^+/7%S(`!(BX#@
M````2(MH".A)W?__BSU;<R``#[:8K0```.@WW?__2(M`"(/C?P^W0"#!X`<)
MPV:)70*+/35S(`#H&-W__XL]*G,@`$B+@.````!(BU@(Z`+=__\QTKZ=7$``
M2(G'Z,/=__^+/05S(`!(B4,HZ.3<__^+/?9R(`!(BX#@````2(M8".C.W/__
M2(N`J`4``(L]V7(@`$B)0S#HN-S__XL]RG(@`$B+@.````!(BU@(Z*+<__\Q
MTDB#N(`!````=!F+/:AR(`#HB]S__TB+@(`!``!(BY"H````BSV/<B``2(E3
M..ANW/__2(N`X````(L]>7(@`$B+0`A(QT!``````.A0W/__2(N`X````(L]
M6W(@`$B+0`A(QT`@`````.@RW/__BSU$<B``2(N`X````$B+6`CH'-S__TB+
M@!@#``!(B4-(2(/$"%M=PV8N#Q^$``````!32(G[BST.<B``Z/';__](C9"8
M`0``2(G>OP,```#H_=O__X7`=`DQP%O##Q]$``"+/>)Q(`#HQ=O__P^W@*@!
M``!F)0#P9CT`0'0<BSW&<2``Z*G;__\/MX"H`0``9B4`\&8]`*!UOTB)W[X"
M````Z*O:__^%P`^4P`^VP%O#D$%454F)]%-(B?VZ_P,``+_:6D``2('L$`0`
M`$B)YF1(BP0E*````$B)A"0(!```,<#HBMW__X7`?FZ-2/](8]F`/!P`=%I(
M8]A(B=J^+P```$B)Y^@7VO__2(7`=$J+/31Q(`#H%]O__TB)V4B)XDB)[DB)
MQ^@6W?__2(N$)`@$``!D2#,$)2@```!U-DB!Q!`$``!;74%<PP\?@`````"%
MR76E#Q]``(L]ZG`@`.C-VO__3(GB2(GN2(G'Z$_:___KM^@8VO__#Q^$````
M``!(@^P(BSV^<"``Z*':__^YTEQ``+J`&T``ONE:0`!(B<=(@\0(Z9;;__]F
M#Q]$``!(@^P(BSV.<"``Z'':__](B<?HN?___XL]>W`@`.A>VO__0;B=7$``
M13')NH!50`!,B<&^!5M``$B)QTB#Q`CIW-O__V9F9BX/'X0``````#'`PV9F
M9F8N#Q^$``````!!5D%5051528GT4TB)^[\<6T``2('L(`0``&1(BP0E*```
M`$B)A"08!```,<!(C70D#.B)]___OB\```!(B=](B<7H6=C__TB%P'0Y2(G>
MOR5;0``QP.BE^/__2(G82(N,)!@$``!D2#,,)2@````/A4\!``!(@<0@!```
M6UU!7$%=05[#2(G?Z"/8__^^,EM``$R)YT&)Q>C3V/__2(7`28G&=*=!O!I;
M0`!!@\4!D$&`/@!-#T3T2(7M=!-,B?9(B>_H&-K__X7`#X2F````3(GWZ-C7
M__^)PDB808!\!O\O=1</'T``@^H!2&/"08!\!O\O0<8$!@!T[40!ZH'Z_P,`
M``^/0O___TB#[`BY4UQ``$&Y-%M``%--B?"Z``0``+X!````,<!(C7PD(.B-
MV___BSW_;B``Z.+8__](C70D($B-D)@!``"_`P```.C<V/__A<!:674<BSW8
M;B``Z+O8__\/MX"H`0``9B4`\&8]`(!T'3'_OC);0`#H[M?__TB%P$F)Q@^%
M(O___^FY_O__2(U\)!"^`0```.B>U___A<!UT$B-="00OR5;0`#H2_?__TB-
M?"00Z$'7___IFO[__^BWU___#Q^```````^V#TB)^(3)=!A(C5<!9I"`^2\/
MM@I(#T3"2(/"`83)=>[SPV9F9BX/'X0``````%532(G[2(/L"$B%_W12#[8O
M0(3M=$KHE=;__TB-5`/_2#G3<A3K)V8/'X0``````$B#Z@%(.=IT%8`Z+W3R
MZP6`.B]T0$B#Z@%(.=-R\D@YTW4R0(#]+W5P#Q^``````+\"````Z#;:__](
MA<!T4;HN````9HD02(/$"%M=PV:0@#HO=0E(@^H!2#G3<O)(*=I(C4("2#T`
M!```=R-(B=Y(@\(!N0`$``"_`+-@`.CMV/__2(/$"+@`LV``6UW#D$B#Q`@Q
MP%M=PTB#Q`B_-%M``%M=Z2?6__\/'X``````2(/L2+\V6T``9$B+!"4H````
M2(E$)#@QP$B+!6`7``!(B40D$$B+!5P7``!(B40D&$B+!5@7``!(B40D($B+
M!507``!(B40D*`^W!5`7``!FB40D,#'`Z$3U__\QP+\_6T``Z#CU__\QP+]'
M6T``Z"SU__\QP+]06T``Z"#U__\QP+]76T``Z!3U__\QP+]G6T``Z`CU__\Q
MP+\<6T``Z/ST__\QP+]S6T``Z/#T__\QP+]]6T``Z.3T__\QP+^'6T``Z-CT
M__\QP+\E6T``Z,ST__\QP+^16T``Z,#T__\QP+^:6T``Z+3T__](C70D##'`
MOZ5;0`#HX_/__TB%P'0/2(G&OWU;0``QP.@/]?__2(UT)`PQP+^V6T``Z+[S
M__](A<!T#TB)QK_(6T``,<#HZO3__TB-="0,,<"_TUM``.B9\___2(7`=#Q(
MB<:_'%M``#'`Z,7T__\QP+[_6T``OU=;0`#HM/3__TB+1"0X9$@S!"4H````
M=5I(@\1(PP\?@`````!(C70D##'`O^-;0`#H1_/__TB%P'022(G&OW-;0``Q
MP.AS]/__ZZR02(UT)"&_]%M``+D*````\Z9UF$B-="0KOW-;0``QP.A,]/__
MZX7HQ=3__P\?1```2(/L&&1(BP0E*````$B)1"0(,<"+!19K(`"#^/]T&4B+
M3"0(9$@S#"4H````=45(@\08PP\?0`!(C70D!#'`OW-;0`#HM_+__TB%P'0B
M#[80A-(/E<"`^C`/E<(/MM(AT(D%R6H@`.NV#Q^``````#'`Z^WH1]3__P\?
M@`````!(@^P(Z`?6__^)Q^BPU?__2(7`=`M(BP!(@\0(PP\?`#'`Z_1F9F8N
M#Q^$``````!!5T%628G^055!5$&]"UQ``%53O0%<0`!(@^Q89$B+!"4H````
M2(E$)$@QP$C'1"00"UQ``$C'1"08`5Q``$R-9"0@2,=$)"`.7$``2,=$)"@$
M7$``2,=$)#`)7$``2,=$)#@;7$``2,=$)$``````ZR9F#Q]$``!(B<?HX-3_
M_TB%P'1C2(7M=#Q)BP0D28GM28/$"$B)Q4B-="0,,<!,B>_HJ?'__TB%P$B)
MPTR)]G0%@#@`=<$QP$R)[^C/\O__2(7M=<1(BT0D2&1(,P0E*````'5O2(/$
M6%M=05Q!74%>05_##Q\`3(GWZ%#2__](B=])B<?H1=+__TF-?`<"Z"O6__](
M@^P(2,?"_____TB)QU-)B<=!N3);0`!-B?"Y4UQ``+X!````,<#H'];__TR)
M_DR)[S'`Z%+R__]86NE`____Z,;2__]F#Q]$``!!5T%6055!5$F)_%53OQQ;
M0`!(@>QX@0``9$B+!"4H````2(F$)&B!```QP$B-="0<2,=$)"`R7$``2,=$
M)"@:6T``2,=$)#``````2,=$)&#(6T``2,=$)&C!6T``2,=$)'`W7$``2,=$
M)'C>6T``2,>$)(`````_7$``2,>$)(@`````````2,=$)$`F7$``2,=$)$A#
M7$``2,=$)%``````Z%CP__](A<!T"8`X``^%2@0``#'`Z,/]__](A<!(B<,/
MA%0$``!(B=_H']'__TB-?``!Z`75__^`.P!)B<5(B<5T-F8N#Q^$``````!$
M#[8#2(GO,<"Y3%Q``$C'PO____^^`0```$B#PP%(@\4"Z.G4__^`.P!UU$B-
M;"1HO\A;0`#K%0\?A```````2(/%"$B+??A(A?]T.TB-="0<,<#HM^___TB%
MP$B)PW3?@#@`=-I(B<?H`O;__X7`=,Y(B=_HUM#__TB%P$B)PW5?9@\?1```
M2(M<)"!(A=L/A%H!``"`.P"]`0```'4EZ4L!```/'P!(8\5(BUS$($B%VP^$
M-P$``(/%`8`[``^$*P$``$B)W^BC]?__A<!TUTB)W^AWT/__2(7`2(G#=,=(
MB=_H%]#__TR)Z8LQ2(/!!(V6__[^_O?6(?*!XH"`@(!TZ(G6P>X0]\*`@```
M#T362(UQ`D@/1,X`TDB#V0-,*>E$C;0(!`0``$UC]DR)]^BZT___055H6EQ`
M`$&Y-%M``$B)QTB)Q4F)V+E17$``2,?"_____[X!````,<#HK-/__[[``0``
M2(GOZ,_/__^#^/]!64%:#X2"````BST$9R``Z.?0__](C9"8`0``2(GNOP,`
M``#H\]#__X7`#X23````28L,)$B+/1AG(`!)B>BZ(%U``+X!````,<#H#-/_
M_S'`2(N4)&B!``!D2#,4)2@````/A9X)``!(@<1X@0``6UU!7$%=05Y!7\.0
M,=OIZO[__V8/'X0``````.@KS___1(L(08/Y$0^$;/___TF+#"1(BSVK9B``
M28GHNN!<0`"^`0```#'`Z)_2__\QP.N1#Q\`BSU*9B``Z"W0__\/MX"H`0``
M9B4`\&8]`$`/A4W___^+/2IF(`#H#=#__XN8L`$``.@RT?__.<,/A2____^+
M/0QF(`#H[\___P^W@*@!``!F)?\!9CW``0^%#____TR)]^A2TO__2(UT)!R_
M!%Q``$B)PS'`Z%[M__](A<!(B<</A*@(``#HC<[__TF+/"1(B<;H@?7__TB%
MP$F)Q0^$BP@``$R)[^@=SO__@_@#?CA(8]"_7UQ``+D%````28UT%?SSIG4B
M@_@$#X2`!@``@^@$2)A!@'P%_R\/A&\&```/'X0``````#'`Z.GY__^%P'45
M,?9,B>_HZ\W__X7`B00D#X5(`0``OO];0`"_<UM``#'`Z/_M___H2M'__VB=
M7$``4$C'PO____]!N31;0`!)B>BY>%Q``+X!````2(G?,<#HD-'__T4QY%A:
MZU!F#Q^$``````#HF\W__X,X$75/Z`'1__]!@\0!2(/L"$&Y-%M``&B=7$``
M051)B>A0N89<0`!(Q\+_____O@$```!(B=\QP.@]T?__2(/$(+[``0``2(G?
MZ%S-__^#^/]TITB)[^C?S___2(G>OQQ;0``QP.A0[?__2(G?Z+CY__](B=CI
MMOW__TB)QTB)!"3HI/G__TB+!"1(B<?H*,W__^F9_?__OR9<0`"]`0```.L7
M#Q^``````$ACQ8/%`4B+?,1`2(7_="M(C70D'#'`Z+3K__](A<!TWX`X`'3:
M2(G'Z.+,__](A<!(B<-TRNE>^___0+<-NRM<0`#I7OO__[H"````2,?&[O__
M_XG'08G&Z"+0__](C;0D8`$``+H&````1(GWZ+W.__^`O"1@`0```'4.@+PD
M80$``$,/A.8%``"+/"0QTC'VZ.G/__^XB:O-[TC'A"20`````2-%9TC'A"2H
M````=E0R$$B)A"28````N/[<NIA(QX0DN`````````!(B80DH````+CPX=+#
M2,>$),``````````2(F$)+````!(C80DR````,>$)`@!````````2(E$)`AF
M+@\?A```````BSPD2(VT)&`!``"Z`(```.@+SO__A<!)B<=!B<0/CHH!``!(
MB[0DN````$ECUXT$UD@YQDB+M"3`````=@1(@\8!2(F$)+@```!(8X0D"`$`
M`$C!ZAU(`?)(B90DP````(7`#X0W`0``0;Q`````2(V\!,@```!(C;0D8`$`
M`$$IQ$4YYT4/3N=-8^Q,B>KH',W__XN$)`@!``!$`>"#^$")A"0(`0``#X52
M____1(GX2(V\))````!$*>!!B<1(C80D8`$``$D!Q>A1TO__D$&#_#\/CIT`
M``!%B>9-B>])BP](C;PDD````$&#[D!)@\=`2(F,),@```!)BT_(2(F,)-``
M``!)BT_02(F,)-@```!)BT_82(F,).````!)BT_@2(F,).@```!)BT_H2(F,
M)/````!)BT_P2(F,)/@```!)BT_X2(F,)``!``#HS-'__T&#_C]_AD&#[$!$
MB>+!Z@:)T,'B!DB#P`%!*=1(P>`&20'%2(M\)`A)8]2Y2````$R)[NC4R___
M1(FD)`@!``#I9_[__P\?@`````!,C:PD8`$``.DC____BSPDZ,O+__],BZ0D
MN````$R+K"3`````3(G@2,'H`X/@/XU(`4ACT,:$%,@```"`@_DX#X^+`@``
MNC<```!(8\DIPDB-C`S`````2&/"2(/X"$B-40@/@\@"``"H!`^%SP,``$B%
MP'0,J`+&00@`#X7]`P``3(GH2(V\))````!$B*PD`P$``$C!Z!A$B*0D!P$`
M`$R-O"0P`0``B(0D``$``$R)Z$C!Z!!-C7<HB(0D`0$``$R)Z$R-K"01`0``
M2,'H"(B$)`(!``!,B>!(P>@8B(0D!`$``$R)X$C!Z!"(A"0%`0``3(G@38G\
M2,'H"(B$)`8!``#H=M#__TB+A"20````2(G"B(0D$P$``$C!ZAA$#[;"B)0D
M$`$``$B)PDC!ZA"(E"01`0``2(G"2(N$))@```!(P>H(B)0D$@$``$B)PHB$
M)!<!``!(P>H8B)0D%`$``$B)PDC!ZA"(E"05`0``2(G"2(N$)*````!(P>H(
MB)0D%@$``$B)PHB$)!L!``!(P>H8B)0D&`$``$B)PDC!ZA"(E"09`0``2(G"
M2(N$)*@```!(P>H(B)0D&@$``$B)PHB$)!\!``!(P>H8B)0D'`$``$B)PDC!
MZA"(E"0=`0``2(G"2(N$)+````!(P>H(B)0D'@$``$B)PHB$)",!``!(P>H8
MB)0D(`$``$B)PDC!ZA"(E"0A`0``2(G"2,'J"(B4)"(!``#I"0```$4/MD4`
M28/%`4R)YS'`N4Q<0`!(Q\+_____O@$```!)@\0"Z,C+__]-.?1UT\:$)%@!
M````:)U<0`!!5[EI7$``O@$```!!N31;0`!)B>A(Q\+_____2(G?,<#HD,O_
M_UE>Z6+Z__]-BV0D"$V%Y`^$B_G__TR)Y^ACQ___2(/X`P^&>?G__TF-=`3\
MOV1<0`"Y!0```/.F30]$[.E?^?__NC\```!(8\DIPDB-C`S`````B="#^`A(
MC5$(#X.(````J`0/A5H!``"%P'0,J`+&00@`#X5>`0``2(V\))````#H:<[_
M_TB-E"3(````N0<````QP$B)U_-(J^E1_?__2,=!"`````!(@\$02,=$$/@`
M````2(/A^$@IRD@!T$B#X/A(@_@(#X(D_?__2(/@^#'22,<$$0````!(@\((
M2#G"<N_I"/W__TC'00@`````2(/!$(G&2(/A^$C'1#+X`````$@IR@'0@^#X
M@_@(#X)D____@^#X,=*)UH/""#G"2,<$,0````!R[^E)____@+PD8@$``$$/
MA0SZ__^`O"1C`0``0P^%_OG__X"\)&0!``!(#X7P^?__@+PD90$``$4/A>+Y
M__]$BS0DN@(```!(Q\;&____1(GWZ+_)__](C;0D8`$``+HI````1(GWZ%K(
M__]HG5Q``$B-A"1H`0``4.DS_O__#Q^``````,=!"`````#'1!#\`````.DN
M_/__QT$(`````,=$`OP`````Z:+^__]%,<!F1(E$`O[IE/[__TV++"3I;/?_
M_S'_9HE\$/[I]_O__^A0QO__055!5%532(/L&(L]^%P@`&1(BP0E*````$B)
M1"0(,<#HR\;__TB-="0$QH"I`````;]76T``,<#H4^3__TB%P'0)@#@Q#X1E
M`@``,<#H7N___XL]L%P@`.B3QO__N0L```"Z`0```+Z77$``2(G'Z*S&__](
MA<`/A+0```"#/0QA(``!2(M`$$R+8"@/CI\````Q[;L!````ZS`/'T0``$F+
M=1!(BP7=8"``2&/32(L\T.CYQO__A<!U98L%SV`@`(/#`8/%`3G8?EN+/3=<
M(`#H&L;__S')2&/53(GF2(G'Z-K'__](A<!T-4R+*$&+10PE``0@`#T`!```
M=**+/01<(`#HY\7__TR)[KD"````,=)(B<?H=<7__TB)QNN$BP5J8"``C5#_
M.>H/A#\!``"+/=%;(`#HM,7__[D#````N@$```"^G%Q``$B)Q^C-Q?__2(7`
M2(G#=#-(BT`0BSVC6R``2(LHZ(/%__^ZGEQ``$B)QTB)[N@#Q?__2(M#$$B+
M&/9##D`/A2T"``"+/71;(`#H5\7__[D#````N@$```"^HUM``$B)Q^APQ?__
M2(7`2(G%=#U(C70D!#'`OR5;0`#HQ^+__TB%P$B)PP^$<P$``$B+11"+/2E;
M(`!,BR#H"<7__TB)VDB)QTR)YNB+Q/__BST-6R``Z/#$__](C70D!,:`J0``
M``"_'%M``#'`Z'CB__](A<!(B<-(B05S7R``#X25````OL`!``!(B<?HB,/_
M_XU0`8/Z`78)@_@1#X6<`0``2(M$)`AD2#,$)2@````/A8,!``!(@\086UU!
M7$%=PP\?A```````@_@!#XZX_O__NP$```!FD(L]@EH@`(/#`>ABQ/__3(GF
M2(G'Z%?#__\Y'?%>(`!_W^F+_O__9BX/'X0``````(!X`0`/A)C]___IC/W_
M_Y!(BSW!7B``Z,3P__](A<!(B07"7B``#X3Z````2(M%$$R+):%>(`!(BQB+
M0PPE``0@`#T`!```#X69````2(M[$$R)YNB7Q?__08G$2(M%$$B+&(M3#('B
M``0@`('Z``0``'502(M3$$B+!5E>(`!$B>&_H%U``$B+,#'`Z)_$__\/'X``
M````2(L%.5X@`(L]LUD@`$R+($B+11!(BQCHC,/__TR)YDB)W^@!Z/__Z8'^
M__^+/8Y9(`#H<</__S'2N0(```!(B=Y(B<?H_\+__TB)PNN2BSUL62``Z$_#
M__^Y`@```$B)QS'22(G>Z-W"__](B<?I1O___XL]1UD@`.@JP___2(G>2(G'
MZ(_$___IN/W__[]X74``Z`#$___H:\+__XG!2(L%FET@`$B)VK_(74``2(LP
M,<#HX,/__U532(G]2(/L".C"ZO__#[8(2(G#A,ET&DB-4`$/'T``@/DO#[8*
M2`]$VDB#P@&$R77N,<#H5^W__X7`=!U(A>UT&(!]``!T$KY:7$``2(G?Z$O#
M__](.=AT!TB#Q`A;7<-(@\0(2(GO6UWIH>/__Y!(@^P(BSV.6"``Z''"__^^
M_____TB)Q^@DPO__BSUV6"``Z%G"__\QTKX`/T``2(G'2(/$".FVQ/__9@\?
M1```2(T%`5@@`$B%P'0,2(L-]5<@`.D(PO__,<GK]P\?0`!!5T&)_T%628GV
M055)B=5!5$R-)5A3(`!52(TM6%,@`%-,*>4QVTC!_0-(@^P(Z#7`__](A>UT
M'@\?A```````3(GJ3(GV1(G_0?\4W$B#PP%(.>MUZDB#Q`A;74%<05U!7D%?
MPV9F+@\?A```````\\,``$B#[`A(@\0(PP````$``@`E<R\E<P`O<')O8R]S
M96QF+V5X90!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS
M.CI005(Z.D)/3U0`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU
M3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!0
M05)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?
M05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]4
M35!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@!005)?0TQ%04X]`#$`3$E"4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!3
M2$Q)0E]0051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!
M344`)3`R>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E
M<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`
M+64`+2T``````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M``!P97)L>'-I+F,``````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!E>&5C=71I;VX@;V8@
M)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M``````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B
M?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA
M9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C
M(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N
M("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE
M;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL
M(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!
M4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA
M<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M
M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y
M<R`E14Y6*2!["F1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*
M?0IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F
M.PIS965K(%]&2"P@+3@L(#(["G)E860@7T9(+"`D8G5F+"`X.PIL87-T('5N
M;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*<V5E:R!?1D@L("TQ,BP@,CL*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB
M+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT
M96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E
M<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T
M<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C
M(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z
M('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z
M+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I
M(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`H)&]U
M="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*:68@*"1O
M=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D
M;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D
M9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%2
M7U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A
M<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PIO<&5N
M(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D
M;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PI]"F5L<V4@>PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*
M?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL
M96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R![
M"FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT
M('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@
M;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA
M;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS
M92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE
M;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN
M="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E("1O=70["GT*;W!E;B!M
M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E
M='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T
M(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<
M,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE
M<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G
M.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R
M.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]
M*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X
M:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O
M=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F
M:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#
M86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@
M)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A
M.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2
M(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@
M.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@
M/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D
M:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!S;W)T('L*;&5N9W1H*"1B*2`\/3X@;&5N9W1H
M*"1A*0I](&=R97`@>PHA+T)31%!!3B\*?2!G<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["FUY("5F:6QE<SL*+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE
M<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B1F:6QE<WLD7WTK*R!F;W(@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM
M>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE
M(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI
M7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L
M<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@
M)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A
M8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*
M<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\
M)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO
M9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z
M<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R
M:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I
M;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]
M"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C
M:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A
M8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E
M('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM
M;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]
M"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD[
M"B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*
M<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D
M0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I
M*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*
M<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A
M;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5
M=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE
M=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF
M("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O
M9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*
M<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R
M96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]
M"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE
M(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L
M;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X
M="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE
M(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["FEF("@D14Y6>U!!4E]#3$5!3GTI
M('L*=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["G!U<V@@0'1M
M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I
M;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D
M9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L
M("1F:6QE;F%M92D["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]
M?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D
M,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%
M3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q
M*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L
M("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US
M("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O
M;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA
M;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII
M9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO
M.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?
M:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@
M*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@
M4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G
M+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2![
M"B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@
M97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A
M;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D
M14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L
M<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A
M;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I
M*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,
M14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````````````````````````P$,!
M&P,[[````!P```"X@/__.`$``/B$__]@!@``0X?__P@!``!(B/__8`$``.B?
M__^P`0``J*#__Q`"```HH?__.`(``&BC__^(`@``V*3__\@"``!(IO__^`(`
M`,BF__\8`P``F*?__U`#``#(I___:`,``!BH__^``P``**C__Y@#``#XJ?__
M\`,``"BJ__\(!```"*O__U@$``#HK/__>`0``&BM__^8!```F*W__[@$``#H
MKO__&`4``%B[___0!0``6+___Q`&``#(O___2`8```C`__^(!@``*,#__Z`&
M``"8P/__Z`8````````4``````````%Z4@`!>!`!&PP'")`!!Q`4````'```
M`#.&__\T```````````````4``````````%Z4@`!>!`!&PP'")`!```D````
M'````'A___]`!`````X01@X82@\+=PB``#\:.RHS)"(`````3````$0```#@
MAO__FQ<```!"#A"/`D(.&(X#1@X@C01"#BB,!4,.,(8&00XX@P='#M`%`W07
M"@XX00XP00XH0@X@0@X80@X00@X(00L```!<````E````#">__^W`````$(.
M$(\"0@X8C@-%#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)Q"@XX0PXP00XH0@X@
M0@X80@X00@X(0@M<#CA!#C!!#BA"#B!"#AA"#A!"#@@D````]````)">__]]
M`````$$.$(,"1PX@`FX*#A!!#@A!"P``````3````!P!``#HGO__.0(```!"
M#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=*#E`#'@$*#CA!#C!!#BA"
M#B!"#AA"#A!"#@A$"P`````\````;`$``-B@__]D`0```$(.$(T"0@X8C`-!
M#B"&!$$.*(,%2@[``7L*#BA!#B!!#AA"#A!"#@A'"P``````+````*P!```(
MHO__9@$```!!#A"&`D$.&(,#1`X@`UT!#AA!#A!!#@@`````````'````-P!
M``!(H___?P````!!#A"#`FD*#@A&"P).#@@T````_`$``*BC___(`````$(.
M$(P"00X8A@-$#B"#!%0.L`@">0H.($$.&$$.$$(."$@+`````!0````T`@``
M0*3__RH`````1`X080X(`!0```!,`@``6*3__T0`````1`X0>PX(`!0```!D
M`@``D*3__P,``````````````%0```!\`@``B*3__\D!````0@X0C@)"#AB-
M`T(.((P$00XHA@5$#C"#!D\.T`@"8@H.,$$.*$$.($(.&$(.$$(."$$+`HD.
MV`A,#N`(?0[8"$$.T`@````4````U`(```"F__\D``````````````!,````
M[`(``!BF___9`````$$.$(8"00X8@P-'#B`"<@H.&$$.$$$."$,+=PH.&$8.
M$$$."$(+1`H.&$,.$$$."$$+1`X81@X000X(`````!P````\`P``J*;__]L!
M````1`Y0`WP!"@X(2`L`````'````%P#``!HJ/__>0````!$#B!O"@X(10L`
M```````<````?`,``,BH__\D`````$0.$%@*#@A$"P```````%P```"<`P``
MV*C__TH!````0@X0CP)"#AB.`T4.((T$0@XHC`5'#C"&!D$..(,'20Z0`0*^
M"@XX00XP00XH0@X@0@X80@X00@X(1`MA#I@!2PZ@`6L.F`%!#I`!`````+0`
M``#\`P``R*G__W`,````0@X0CP)"#AB.`T(.((T$0@XHC`5$#C"&!D$..(,'
M3`ZP@P(##P(.N(,"10[`@P)Y#KB#`D(.L(,"`FP*#CA!#C!!#BA"#B!"#AA"
M#A!"#@A""P-K`0ZX@P)!#L"#`F@.N(,"00ZP@P)B#KB#`DL.P(,"0@[(@P)$
M#M"#`E\.L(,"`X,%#KB#`D(.P(,"90ZX@P)!#K"#`@.9`0H.N(,"20[`@P),
M"P`\````M`0``("U__\`!````$(.$(T"0@X8C`-!#B"&!$$.*(,%1`Y``U<"
M"@XH00X@00X80@X00@X(20L`````-````/0$``!`N?__;P````!!#A"&`D$.
M&(,#1PX@`E4*#AA!#A!!#@A!"T0.&$0.$$$."``````4````+`4``'BY__\Z
M`````$0.$'$."``D````1`4``)!^__]+`@```$$.$(,"1`Y``[P!"@X000X(
M00L`````%````&P%``!XN?__'```````````````1````(0%``"`N?__90``
M``!"#A"/`D4.&(X#10X@C01%#BB,!4@.,(8&2`XX@P=-#D!L#CA!#C!!#BA"
M#B!"#AA"#A!"#@@`%````,P%``"HN?__`@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!`(D```````"`B0``````````````````!
M``````````$``````````0`````````*`@````````$`````````%0(`````
M```!`````````!\"`````````0````````!N`@````````$`````````M@,`
M```````,`````````+@:0```````#0````````#$6D```````!D`````````
MP*U@```````;``````````@`````````&@````````#(K6```````!P`````
M````"`````````#U_O]O`````*`"0```````!0````````!H#4````````8`
M````````J`-````````*`````````"8%````````"P`````````8````````
M`!4````````````````````#``````````"P8````````@````````!(!@``
M`````!0`````````!P`````````7`````````'`40```````!P````````#@
M$T````````@`````````D``````````)`````````!@`````````_O__;P``
M``!@$T```````/___V\``````@````````#P__]O`````(X20```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#8K6````````````````````````````#V&D````````8;
M0```````%AM````````F&T```````#8;0```````1AM```````!6&T``````
M`&8;0```````=AM```````"&&T```````)8;0```````IAM```````"V&T``
M`````,8;0```````UAM```````#F&T```````/8;0```````!AQ````````6
M'$```````"8<0```````-AQ```````!&'$```````%8<0```````9AQ`````
M``!V'$```````(8<0```````EAQ```````"F'$```````+8<0```````QAQ`
M``````#6'$```````.8<0```````]AQ````````&'4```````!8=0```````
M)AU````````V'4```````$8=0```````5AU```````!F'4```````'8=0```
M````AAU```````"6'4```````*8=0```````MAU```````#&'4```````-8=
M0```````YAU```````#V'4````````8>0```````%AY````````F'D``````
M`#8>0```````1AY```````!6'D```````&8>0```````=AY```````"&'D``
M`````)8>0```````IAY```````"V'D```````,8>0```````UAY```````#F
M'D```````/8>0```````!A]````````6'T``````````````````````````
M``#_____`````!!>0```````1T-#.B`H1&5B:6%N(#0N.2XQ+3$X*2`T+CDN
M,0!'0T,Z("A$96)I86X@-"XX+C,M,3,I(#0N."XS```N<VAS=')T86(`+FEN
M=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA
M<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?
M<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A
M=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?
M87)R87D`+FIC<@`N9'EN86UI8P`N9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`
M+F-O;6UE;G0`````````````````````````````````````````````````
M````````````````````````````````````````````````````````"P``
M``$````"`````````#@"0```````.`(````````=````````````````````
M`0```````````````````!,````'`````@````````!8`D```````%@"````
M````(`````````````````````0````````````````````A````!P````(`
M````````>`)```````!X`@```````"0````````````````````$````````
M````````````-````/;__V\"`````````*`"0```````H`(````````$`0``
M``````4`````````"````````````````````#X````+`````@````````"H
M`T```````*@#````````P`D````````&`````0````@`````````&```````
M``!&`````P````(`````````:`U```````!H#0```````"8%````````````
M```````!````````````````````3@```/___V\"`````````(X20```````
MCA(```````#0``````````4``````````@`````````"`````````%L```#^
M__]O`@````````!@$T```````&`3````````@``````````&`````@````@`
M``````````````````!J````!`````(`````````X!-```````#@$P``````
M`)``````````!0`````````(`````````!@`````````=`````0```!"````
M`````'`40```````<!0```````!(!@````````4````,````"``````````8
M`````````'X````!````!@````````"X&D```````+@:````````&@``````
M``````````````0```````````````````!Y`````0````8`````````X!I`
M``````#@&@```````$`$```````````````````0`````````!``````````
MA`````$````&`````````"`?0```````(!\```````"B.P``````````````
M````$````````````````````(H````!````!@````````#$6D```````,1:
M````````"0````````````````````0```````````````````"0`````0``
M``(`````````T%I```````#06@```````%@_```````````````````(````
M````````````````F`````$````"`````````"B:0```````*)H```````#L
M````````````````````!````````````````````*8````!`````@``````
M```8FT```````!B;````````%`8```````````````````@`````````````
M``````"P````#@````,`````````P*U@``````#`K0````````@`````````
M```````````(````````````````````O`````\````#`````````,BM8```
M````R*T````````(````````````````````"````````````````````,@`
M```!`````P````````#0K6```````-"M````````"```````````````````
M``@```````````````````#-````!@````,`````````V*U@``````#8K0``
M`````"`"````````!@`````````(`````````!``````````U@````$````#
M`````````/BO8```````^*\````````(````````````````````"```````
M```(`````````-L````!`````P``````````L&````````"P````````,`(`
M``````````````````@`````````"`````````#D`````0````,`````````
M,+)@```````PL@```````"`````````````````````(````````````````
M````Z@````@````#`````````("R8```````4+(```````"H!```````````
M````````0````````````````````.\````!````,```````````````````
M`%"R````````.@````````````````````$``````````0`````````!````
M`P````````````````````````"*L@```````/@````````````````````!
/````````````````````
